@@ -1,13 +1,15 @@
 package Log::ger;
 
-our $DATE = '2017-07-02'; # DATE
-our $VERSION = '0.012'; # VERSION
+our $DATE = '2017-07-11'; # DATE
+our $VERSION = '0.013'; # VERSION
 
 #IFUNBUILT
 # # use strict;
 # # use warnings;
 #END IFUNBUILT
 
+our $re_addr = qr/\(0x(\w+)/o;
+
 our %Levels = (
     fatal   => 1,
     error   => 2,
@@ -151,10 +153,10 @@ sub run_hooks {
     if ($target eq 'package') {
         unshift @hooks, @{ $Per_Package_Hooks{$target_arg}{$phase} || [] };
     } elsif ($target eq 'hash') {
-        my ($addr) = "$target_arg" =~ /\(0x(\w+)/;
+        my ($addr) = "$target_arg" =~ $re_addr;
         unshift @hooks, @{ $Per_Hash_Hooks{$addr}{$phase} || [] };
     } elsif ($target eq 'object') {
-        my ($addr) = "$target_arg" =~ /\(0x(\w+)/;
+        my ($addr) = "$target_arg" =~ $re_addr;
         unshift @hooks, @{ $Per_Object_Hooks{$target_arg}{$phase} || [] };
     }
 
@@ -183,11 +185,11 @@ sub add_target {
         unless ($replace) { return if $Package_Targets{$target_arg} }
         $Package_Targets{$target_arg} = $args;
     } elsif ($target eq 'object') {
-        my ($addr) = "$target_arg" =~ /\(0x(\w+)/;
+        my ($addr) = "$target_arg" =~ $re_addr;
         unless ($replace) { return if $Object_Targets{$addr} }
         $Object_Targets{$addr} = [$target_arg, $args];
     } elsif ($target eq 'hash') {
-        my ($addr) = "$target_arg" =~ /\(0x(\w+)/;
+        my ($addr) = "$target_arg" =~ $re_addr;
         unless ($replace) { return if $Hash_Targets{$addr} }
         $Hash_Targets{$addr} = [$target_arg, $args];
     }
@@ -203,8 +205,18 @@ sub init_target {
         init_args  => $init_args,
     );
 
-    my $formatter =
-        run_hooks('create_formatter', \%hook_args, 1, $target, $target_arg);
+    my %formatters;
+    run_hooks(
+        'create_formatter', \%hook_args,
+        # collect formatters, until a hook instructs to stop
+        sub {
+            my ($hook, $hook_res) = @_;
+            my ($formatter, $flow_control, $fmtname) = @$hook_res;
+            $fmtname = 'default' if !defined($fmtname);
+            $formatters{$fmtname} ||= $formatter;
+            $flow_control;
+        },
+        $target, $target_arg);
 
     my $layouter =
         run_hooks('create_layouter', \%hook_args, 1, $target, $target_arg);
@@ -212,13 +224,15 @@ sub init_target {
     my $routine_names = {};
     run_hooks(
         'create_routine_names', \%hook_args,
+        # collect routine names, until a hook instructs to stop.
         sub {
             my ($hook, $hook_res) = @_;
-            my $rn = $hook_res->[0] or return;
+            my ($rn, $flow_control) = @$hook_res;
+            $rn or return;
             for (keys %$rn) {
                 push @{ $routine_names->{$_} }, @{ $rn->{$_} };
             }
-            $hook_res->[1];
+            $flow_control;
         },
         $target, $target_arg);
 
@@ -237,9 +251,10 @@ sub init_target {
         }
         my $mllogger0;
         for my $rn (@rn) {
-            my ($rname, $lname) = @$rn;
+            my ($rname, $lname, $fmtname) = @$rn;
             my $lnum = $Levels{$lname} if defined $lname;
             my $routine_name_is_ml = !defined($lname);
+            $fmtname = 'default' if !defined($fmtname);
 
             my $logger;
             my ($logger0, $logger0_is_ml);
@@ -281,6 +296,8 @@ sub init_target {
                     last;
                 }
 
+                my $formatter = $formatters{$fmtname}
+                    or die "Formatter named '$fmtname' not available";
                 if ($formatter) {
                     if ($layouter) {
                         if ($logger0_is_ml) {
@@ -441,7 +458,7 @@ sub get_logger {
 
     my $caller = caller(0);
     $args{category} = $caller if !defined($args{category});
-    my $obj = []; $obj =~ /\(0x(\w+)/;
+    my $obj = []; $obj =~ $re_addr;
     my $pkg = "Log::ger::Obj$1"; bless $obj, $pkg;
     add_target(object => $obj, \%args);
     init_target(object => $obj, \%args);
@@ -463,7 +480,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
